---
permalink: /
fbcontact: true
nobreadcrumbs: true
---

# KMUHelper

Willkommen in der KMUHelper-Dokumentation!

Hier finden Sie alles, was Sie über den KMUHelper wissen müssen!

## Inhalt

- [Geschichte](history.md)
- [Funktionen](functions.md)
- [Installation](installation.md)
- [Benutzerhandbuch](manual/README.md)

- [Unterstützt den KMUHelper](support.md)

## Kontakt

Wenn Sie mich kontaktieren möchten, finden Sie [hier](<{{ site.kontakt_url }}>) diverse Möglichkeiten dazu.
